==> smartdoc-1.0.0.20030113.zip: src/jp/gr/java_conf/jaba2/xml/relaxng/rRelaxng/IRVisitor.java <==
package jp.gr.java_conf.jaba2.xml.relaxng.rRelaxng;

/**
 * @version relaxNg.rxm 1.0 (Tue Dec 17 16:01:35 GMT+09:00 2002)
 * @author  Relaxer 1.0RCb (http://www.relaxer.org)
 */
public interface IRVisitor {
    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNGrammar visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNGrammar visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNDefine visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNDefine visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNData visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNData visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNParam visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNParam visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNElement visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNElement visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNNsName visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNNsName visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNExcept visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNExcept visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNName visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNName visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNAnyName visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNAnyName visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNNameChoice visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNNameChoice visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNAttribute visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNAttribute visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNValue visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNValue visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNRef visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNRef visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNList visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNList visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNTextChoice visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNTextChoice visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNTextOptional visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNTextOptional visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNTextOneOrMore visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNTextOneOrMore visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNTextZeroOrMore visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNTextZeroOrMore visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNText visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNText visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNNotAllowed visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNNotAllowed visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNEmpty visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNEmpty visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNExternalRef visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNExternalRef visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNParentRef visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNParentRef visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNChoice visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNChoice visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNInterleave visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNInterleave visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNMixed visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNMixed visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNZeroOrMore visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNZeroOrMore visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNGroup visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNGroup visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNOptional visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNOptional visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNOneOrMore visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNOneOrMore visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNStart visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNStart visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNInclude visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNInclude visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNDiv visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNDiv visitable);
}

==> smartdoc-1.0.0.20031106.zip: src/jp/gr/java_conf/jaba2/xml/relaxng/rRelaxng/IRVisitor.java <==
package jp.gr.java_conf.jaba2.xml.relaxng.rRelaxng;

/**
 * @version relaxNg.rxm 1.0 (Fri Oct 31 17:09:08 JST 2003)
 * @author  Relaxer 1.0b (http://www.relaxer.org)
 */
public interface IRVisitor {
    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNGrammar visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNGrammar visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNStart visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNStart visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNAttribute visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNAttribute visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNNsName visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNNsName visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNExcept visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNExcept visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNName visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNName visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNAnyName visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNAnyName visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNNameChoice visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNNameChoice visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNDefine visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNDefine visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNElement visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNElement visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNData visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNData visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNParam visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNParam visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNValue visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNValue visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNRef visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNRef visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNTextOneOrMore visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNTextOneOrMore visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNText visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNText visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNNotAllowed visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNNotAllowed visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNEmpty visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNEmpty visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNTextChoice visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNTextChoice visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNTextOptional visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNTextOptional visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNTextZeroOrMore visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNTextZeroOrMore visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNList visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNList visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNTextGroup visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNTextGroup visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNTextExcept visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNTextExcept visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNExternalRef visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNExternalRef visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNParentRef visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNParentRef visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNGroup visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNGroup visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNChoice visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNChoice visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNInterleave visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNInterleave visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNOneOrMore visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNOneOrMore visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNMixed visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNMixed visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNOptional visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNOptional visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNZeroOrMore visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNZeroOrMore visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNInclude visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNInclude visitable);

    /**
     * Visits this node for enter behavior.
     *
     * @param visitable
     * @return boolean
     */
    boolean enter(RNDiv visitable);

    /**
     * Visits this node for leave behavior.
     *
     * @param visitable
     */
    void leave(RNDiv visitable);
}
